@@ -115,9 +115,11 @@ class ClassificationAnalysis(ModelAnalysis):
         del feature_order
         del target_feature
 
+        self.__model = None
         try:
             self.__model = copy.deepcopy(model)
-        except:
+        except TypeError:
+            print("Unable to save model by normal pickle means~")
             pass
 
         self.__model_name = copy.deepcopy(model_name)
@@ -141,7 +143,7 @@ class ClassificationAnalysis(ModelAnalysis):
 
         # Attempt to save machine learning model
         try:
-            if save_model:
+            if save_model and self.__model:
                 pickle_object_to_file(self.__model,
                                       self.folder_path,
                                       f'{self.__model_name}')
